import { PropType } from 'vue';
export interface Option {
    disabled?: boolean;
    label?: string;
    options?: Option[];
    order?: number;
    selected?: boolean;
    text: string;
    value: number | string;
}
declare const CMultiSelect: import("vue").DefineComponent<{
    /**
     * Enables selection cleaner element.
     *
     * @default true
     */
    cleaner: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Toggle the disabled state for the component.
     */
    disabled: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Provide valuable, actionable feedback.
     *
     * @since 4.6.0
     */
    feedback: {
        type: StringConstructor;
    };
    /**
     * Provide valuable, actionable feedback.
     *
     * @since 4.6.0
     */
    feedbackInvalid: {
        type: StringConstructor;
    };
    /**
     * Provide valuable, actionable invalid feedback when using standard HTML form validation which applied two CSS pseudo-classes, `:invalid` and `:valid`.
     *
     * @since 4.6.0
     */
    feedbackValid: {
        type: StringConstructor;
    };
    /**
     * The id global attribute defines an identifier (ID) that must be unique in the whole document.
     */
    id: {
        type: StringConstructor;
    };
    /**
     * Set component validation state to invalid.
     *
     * @since 4.6.0
     */
    invalid: BooleanConstructor;
    /**
     * Add a caption for a component.
     *
     * @since 4.6.0
     */
    label: {
        type: StringConstructor;
    };
    /**
     * It specifies that multiple options can be selected at once.
     *
     * @default true
     */
    multiple: {
        type: BooleanConstructor;
        default: boolean;
        required: false;
    };
    /**
     * List of option elements.
     */
    options: {
        type: PropType<Option[]>;
        default: () => never[];
        required: false;
    };
    /**
     * Sets maxHeight of options list.
     *
     * @default 'auto'
     */
    optionsMaxHeight: {
        type: (NumberConstructor | StringConstructor)[];
        default: string;
        required: false;
    };
    /**
     * Sets option style.
     *
     * @values 'checkbox', 'text'
     * @default 'checkbox'
     */
    optionsStyle: {
        type: StringConstructor;
        default: string;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Specifies a short hint that is visible in the search input.
     *
     * @default 'Select...''
     */
    placeholder: {
        type: StringConstructor;
        default: string;
        required: false;
    };
    /**
     * Enables search input element.
     */
    search: {
        type: BooleanConstructor;
        default: boolean;
        required: false;
    };
    /**
     * Sets the label for no results when filtering.
     */
    searchNoResultsLabel: {
        type: StringConstructor;
        default: string;
        required: false;
    };
    /**
     * Enables select all button.
     *
     * @default true
     */
    selectAll: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Sets the select all button label.
     *
     * @default 'Select all options'
     */
    selectAllLabel: {
        type: StringConstructor;
        required: false;
        default: string;
    };
    /**
     * Sets the selection style.
     *
     * @values 'counter', 'tags', 'text'
     * @default 'tags'
     */
    selectionType: {
        type: StringConstructor;
        default: string;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Sets the counter selection label.
     *
     * @default 'item(s) selected'
     */
    selectionTypeCounterText: {
        type: StringConstructor;
        default: string;
        required: false;
    };
    /**
     * Size the component small or large.
     *
     * @values 'sm', 'lg'
     */
    size: {
        type: StringConstructor;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Add helper text to the component.
     *
     * @since 4.6.0
     */
    text: {
        type: StringConstructor;
    };
    /**
     * Display validation feedback in a styled tooltip.
     *
     * @since 4.6.0
     */
    tooltipFeedback: BooleanConstructor;
    /**
     * Set component validation state to valid.
     *
     * @since 4.6.0
     */
    valid: BooleanConstructor;
    /**
     * Toggle the visibility of multi select dropdown.
     *
     * @default false
     */
    visible: {
        type: BooleanConstructor;
        default: boolean;
        required: false;
    };
}, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>[], unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, "change"[], "change", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * Enables selection cleaner element.
     *
     * @default true
     */
    cleaner: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Toggle the disabled state for the component.
     */
    disabled: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Provide valuable, actionable feedback.
     *
     * @since 4.6.0
     */
    feedback: {
        type: StringConstructor;
    };
    /**
     * Provide valuable, actionable feedback.
     *
     * @since 4.6.0
     */
    feedbackInvalid: {
        type: StringConstructor;
    };
    /**
     * Provide valuable, actionable invalid feedback when using standard HTML form validation which applied two CSS pseudo-classes, `:invalid` and `:valid`.
     *
     * @since 4.6.0
     */
    feedbackValid: {
        type: StringConstructor;
    };
    /**
     * The id global attribute defines an identifier (ID) that must be unique in the whole document.
     */
    id: {
        type: StringConstructor;
    };
    /**
     * Set component validation state to invalid.
     *
     * @since 4.6.0
     */
    invalid: BooleanConstructor;
    /**
     * Add a caption for a component.
     *
     * @since 4.6.0
     */
    label: {
        type: StringConstructor;
    };
    /**
     * It specifies that multiple options can be selected at once.
     *
     * @default true
     */
    multiple: {
        type: BooleanConstructor;
        default: boolean;
        required: false;
    };
    /**
     * List of option elements.
     */
    options: {
        type: PropType<Option[]>;
        default: () => never[];
        required: false;
    };
    /**
     * Sets maxHeight of options list.
     *
     * @default 'auto'
     */
    optionsMaxHeight: {
        type: (NumberConstructor | StringConstructor)[];
        default: string;
        required: false;
    };
    /**
     * Sets option style.
     *
     * @values 'checkbox', 'text'
     * @default 'checkbox'
     */
    optionsStyle: {
        type: StringConstructor;
        default: string;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Specifies a short hint that is visible in the search input.
     *
     * @default 'Select...''
     */
    placeholder: {
        type: StringConstructor;
        default: string;
        required: false;
    };
    /**
     * Enables search input element.
     */
    search: {
        type: BooleanConstructor;
        default: boolean;
        required: false;
    };
    /**
     * Sets the label for no results when filtering.
     */
    searchNoResultsLabel: {
        type: StringConstructor;
        default: string;
        required: false;
    };
    /**
     * Enables select all button.
     *
     * @default true
     */
    selectAll: {
        type: BooleanConstructor;
        required: false;
        default: boolean;
    };
    /**
     * Sets the select all button label.
     *
     * @default 'Select all options'
     */
    selectAllLabel: {
        type: StringConstructor;
        required: false;
        default: string;
    };
    /**
     * Sets the selection style.
     *
     * @values 'counter', 'tags', 'text'
     * @default 'tags'
     */
    selectionType: {
        type: StringConstructor;
        default: string;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Sets the counter selection label.
     *
     * @default 'item(s) selected'
     */
    selectionTypeCounterText: {
        type: StringConstructor;
        default: string;
        required: false;
    };
    /**
     * Size the component small or large.
     *
     * @values 'sm', 'lg'
     */
    size: {
        type: StringConstructor;
        required: false;
        validator: (value: string) => boolean;
    };
    /**
     * Add helper text to the component.
     *
     * @since 4.6.0
     */
    text: {
        type: StringConstructor;
    };
    /**
     * Display validation feedback in a styled tooltip.
     *
     * @since 4.6.0
     */
    tooltipFeedback: BooleanConstructor;
    /**
     * Set component validation state to valid.
     *
     * @since 4.6.0
     */
    valid: BooleanConstructor;
    /**
     * Toggle the visibility of multi select dropdown.
     *
     * @default false
     */
    visible: {
        type: BooleanConstructor;
        default: boolean;
        required: false;
    };
}>> & {
    onChange?: ((...args: any[]) => any) | undefined;
}, {
    search: boolean;
    invalid: boolean;
    visible: boolean;
    disabled: boolean;
    valid: boolean;
    tooltipFeedback: boolean;
    multiple: boolean;
    options: Option[];
    cleaner: boolean;
    placeholder: string;
    optionsMaxHeight: string | number;
    optionsStyle: string;
    searchNoResultsLabel: string;
    selectionType: string;
    selectionTypeCounterText: string;
    selectAll: boolean;
    selectAllLabel: string;
}>;
export { CMultiSelect };
